from distutils.core import setup
setup(
    name='nanian',
    version='1.0',
    description='This group is composed of one student who is author',
    author='那年',
    author_email='1009689491@qq.com',
)
